;****************************************************************************
;
; Dr. William T. Verts (C) April 5, 1996
;
; This "Little Language" program paints a printed circuit board for
; a simple switch debouncer using a 7400 quad NAND gate.  The circuit board
; is 1.5 inches wide, by 1.0 inches tall.  All coordinate units are in
; inches.
;
; There are three Window commands listed.  All have Y1 > Y2 in order to
; flip the graphic so that world coordinate <0,0> is at the lower left
; instead of the upper left.  All have an aspect ratio of 1.5:1.0 to
; match the dimensions of the circuit board and the screen.  If you change
; the aspect ratio, you will get a distorted view of the circuit.  The three
; Window commands are:
;
; WINDOW 0.0 1.0 1.0 0.0
; View from the component side of the circuit board, as if via X-RAY.
; Text will appear "backwards" because of the convention that circuit
; traces on the bottom of a circuit board are viewed from above, looking
; through the board as if by X-Ray.  Therefore, text will be right side up
; when looking at the bottom of a physical circuit board, but upside down
; when viewed from above in the diagram.
;
; WINDOW 1.5 1.0 0.0 0.0
; View from the solder side of the circuit board.  Text will appear
; right side up.
;
; WINDOW 0.5 0.7 1.1 0.3
; View from component side, but only the middle 0.6 by 0.4 inches.  This is
; to show the effects of changing the window to focus in on a particular
; region.
;
;****************************************************************************

Procedure Main
	Font		"DATAFONT.FNT"
	Screen		300 200		; Aspect Ratio 1.5:1
	Window		0.0 1.0 1.5 0.0	; Viewed from component side (XRAY)
;	Window		1.5 1.0 0.0 0.0	; Viewed from solder side of board
;	Window		0.5 0.7 1.1 0.3	; Middle 0.6 x 0.4 inches
	Viewport_All
	Call		PC_Board
End

;****************************************************************************

Procedure PC_Board
	;-------------------------------
	; Initialization
	;-------------------------------

	Line_Width	0

	;-------------------------------
	; Board Background
	;-------------------------------

	Call		Green
	Filled_Rectangle 0.0 0.0 1.5 1.0

	;-------------------------------
	; Tenth-Inch Grid (optional)
	;-------------------------------

	Call		Grid

	;-------------------------------
	; Circuit Traces
	;-------------------------------

	Line_Width	0.025		; 1/40 inch wide traces
	Call		Yellow

	Move_To		0.2  0.7	; Top Input Line (+5)
	Line_To		0.5  0.7

	Move_To		0.2  0.6	; Input Line (Set)
	Line_To		0.55 0.6
	Call		Turn
	Line_To		0.6  0.65
	Call		Turn
	Line_To		0.6  0.7

	Move_To		0.2  0.5	; Input Line (Reset)
	Line_To		0.45 0.5
	Call		Turn
	Line_To		0.5  0.45
	Call		Turn
	Line_To		0.5  0.4

	Move_To		0.2  0.4	; Input Line (Disable)
	Line_To		0.3  0.4
	Call		Turn
	Line_To		0.4  0.3
	Call		Turn
	Line_To		0.85 0.3
	Call		Turn
	Line_To		0.9  0.35
	Call		Turn
;	Line_To		0.9  0.4
;	Call		Turn
	Line_To		0.9  0.5
	Call		Turn
	Line_To		1.0  0.6
	Call		Turn
	Line_To		1.0  0.7

	Move_To		0.2  0.3	; Input Line (Ground)
	Line_To		0.3  0.3
	Call		Turn
	Line_To		0.4  0.2
	Call		Turn
	Line_To		1.0  0.2
	Call		Turn
	Line_To		1.1  0.3
	Call		Turn
	Line_To		1.1  0.4

	Move_To		1.1  0.7	; Output Line (Q)
	Line_To		1.3  0.7

	Move_To		1.0  0.4	; Output Line (Not-Q)
	Line_To		1.0  0.45
	Call		Turn
	Line_To		1.05 0.5
	Call		Turn
	Line_To		1.3  0.5

	Move_To		0.6  0.4
	Line_To		0.6  0.5
	Call		Turn
	Line_To		0.65 0.55
	Call		Turn
	Line_To		0.65 0.75
	Call		Turn
	Line_To		0.7  0.8
	Call		Turn
	Line_To		0.75 0.8
	Call		Turn
	Line_To		0.8  0.75
	Call		Turn
	Line_To		0.8  0.7
	Call		Turn
	Line_To		0.9  0.7

	Move_To		0.7  0.7
	Line_To		0.7  0.4
	Call		Turn
	Line_To		0.8  0.4

	;*******************************
	; Connectors & Pads
	;*******************************

	Line_Width	0

	;-------------------------------
	; Input Connectors
	;-------------------------------

 	Move_To		0.2 0.3
	Call		Medium_Pad
	Move_To		0.2 0.4
	Call		Medium_Pad
	Move_To		0.2 0.5
	Call		Medium_Pad
	Move_To		0.2 0.6
	Call		Medium_Pad
	Move_To		0.2 0.7
	Call		Medium_Pad

	;-------------------------------
	; Output Connectors
	;-------------------------------

	Move_To		1.3 0.5
	Call		Medium_Pad
	Move_To		1.3 0.7
	Call		Medium_Pad

	;-------------------------------
	; Chip Pads
	;-------------------------------

	Push
	Translate	0.5 0.4
	Call		IC_14_Pin
	Pop

	Move_To		0.4 0.4
	Call		Dot

	;-------------------------------
	; Mounting Holes in Corners
	;-------------------------------

	Move_To		0.1 0.1
	Call		Large_Pad
	Move_To		0.1 0.9
	Call		Large_Pad
	Move_To		1.4 0.1
	Call		Large_Pad
	Move_To		1.4 0.9
	Call		Large_Pad

	;*******************************
	; Text Labels
	;*******************************

	Line_Width	0		; One pixel wide text lines
	Call		White		;
	Text_Scale	-0.06 0.08	; -X Means Text Goes Right to Left

	Move_To		1.2 0.875
	String		"Switch Debouncer"

	Move_To		0.425 0.75
	String		"+5V"

	Move_To		1.3 0.2
	String		"Gnd"

	Move_To		1.275 0.05
	String		"(C) WT Verts 1996"

	Text_Scale	-0.05 0.07
	Move_To		1.25 0.575
	String		"7400"

	;-------------------------------

	Push
	    Rotate	90		; Rotate 90 degrees around <0,0>

	    Push			; Plot "Output" at <1.45,0.75>
	    Translate	1.45 0.75	; vertically from top to bottom
	    Move_To	0 0		;
	    String	"Output"	;
	    Pop				;

	    Push			; Plot "Input" at <0.1, 0.65?
	    Translate	0.1 0.65	; vertically from top to bottom
	    Move_To	0 0		;
	    String	"Input"		;
	    Pop				;
	Pop
End

;---------------------------------------

Procedure Grid
    Push
	Line_Width	0
	Call		Red
	Push
	Perform		Step_Y  9
	Pop

	Push
	Perform		Step_X  14
	Pop
    Pop
End

Procedure Step_X
	Translate	0.1 0.0
	Line		0.0 0.0 0.0 1.0
End

Procedure Step_Y
	Translate	0.0 0.1
	Line		0.0 0.0 1.5 0.0
End
;---------------------------------------
; Plot two rows of 7 pins the rows
; separated by 0.3 inches, relative to
; the origin of the current coordinate
; system.

Procedure IC_14_Pin
    Push
	Push
	Perform		Pad_and_Step  7
	Pop

	Translate	0.0 0.3

	Push
	Perform		Pad_and_Step  7
	Pop
    Pop
End

;---------------------------------------
; Place a small pad at origin, then
; shift coordinate system to the right
; by 0.1 inches to set up for the next
; pad, if needed.

Procedure Pad_and_Step
	Move_To		0 0
	Call		Small_Pad
	Translate	0.1 0.0
End

;---------------------------------------
; Circle to be used between Line_To
; commands to compensate foe turning
; lines (fills in gap).

Procedure Turn
	Filled_Circle	0.0125 16
End ;

;---------------------------------------

Procedure Dot
	Call		Yellow
	Call		Small_Hole
End

Procedure Small_Pad
	Call		Yellow
	Call		Small_Circle
	Call		Black
	Call		Small_Hole
End

Procedure Medium_Pad
	Call		Yellow
	Call		Medium_Circle
	Call		Black
	Call		Medium_Hole
End

Procedure Large_Pad
	Call		Yellow
	Call		Large_Circle
	Call		Black
	Call		Large_Hole
End

;---------------------------------------

Procedure Small_Circle
	Filled_Circle	0.0250	16
End

Procedure Medium_Circle
	Filled_Circle	0.0400	16
End

Procedure Large_Circle
	Filled_Circle	0.0800	16
End

;---------------------------------------

Procedure Small_Hole
	Filled_Circle	0.0125	16
End

Procedure Medium_Hole
	Filled_Circle	0.0250	16
End

Procedure Large_Hole
	Filled_Circle	0.0500	16
End

;---------------------------------------

Procedure Black
	Color		0 0 0
End

Procedure Blue
	Color		0 0 255
End

Procedure Green
	Color		0 255 0
End

Procedure Cyan
	Color		0 255 255
End

Procedure Red
	Color		255 0 0
End

Procedure Magenta
	Color		255 0 255
End

Procedure Yellow
	Color		255 255 0
End

Procedure White
	Color		255 255 255
End

